.. _installation:

Installation
============

To use ibpmodel, first install it using pip:

.. code-block:: console

   $ pip install ibpmodel

ibpmodel has the following dependencies:

- numpy
- pandas
- matplotlib
- scipy (scipy.special)
- cdflib

The required packages are downloaded and installed automatically during the installation.

ibpmodel can also be installed directly from source. The source code can then be downloaded from IAP GitLab and installed:

.. code-block:: console

   $ git clone https://igit.iap-kborn.de/ibp/ibp-model.git
   $ cd ibpmodel 
   $ pip install .


